@@ -46,10 +46,11 @@ public:
 };
 
 CategoryWidget::CategoryWidget(CategoryConfig *cc, QWidget *parent)
-    : QWidget(parent), mCategoryConfig(cc)
+    : QWidget(parent)
+    , mCategoryConfig(cc)
 {
     QHBoxLayout *topL = new QHBoxLayout(this);
-    topL->setMargin(0);
+    topL->setContentsMargins(0, 0, 0, 0);
     mWidgets = new CategoryWidgetBase(this);
     topL->addWidget(mWidgets);
 
@@ -75,7 +76,6 @@ CategoryWidget::CategoryWidget(CategoryConfig *cc, QWidget *parent)
 
     connect(mWidgets->mColorCombo, &KColorCombo::activated,
             this, &CategoryWidget::handleColorChanged);
-
 }
 
 CategoryWidget::~CategoryWidget()
@@ -97,7 +97,8 @@ void CategoryWidget::setCategories(const QStringList &categoryList)
     mCategoryList.clear();
 
     QStringList cats = mCategoryConfig->customCategories();
-    for (QStringList::ConstIterator it = categoryList.begin(), end = categoryList.end(); it != end; ++it) {
+    for (QStringList::ConstIterator it = categoryList.begin(), end = categoryList.end(); it != end;
+         ++it) {
         if (!cats.contains(*it)) {
             cats.append(*it);
         }
@@ -109,11 +110,9 @@ void CategoryWidget::setCategories(const QStringList &categoryList)
 void CategoryWidget::setSelected(const QStringList &selList)
 {
     clear();
-    QStringList::ConstIterator it;
-
     const bool remAutoCheckChildren = mWidgets->mCategories->autoCheckChildren();
     mWidgets->mCategories->setAutoCheckChildren(false);
-    for (it = selList.begin(); it != selList.end(); ++it) {
+    for (QStringList::ConstIterator it = selList.begin(), end = selList.end(); it != end; ++it) {
         QStringList path = CategoryHierarchyReader::path(*it);
         QTreeWidgetItem *item = mWidgets->mCategories->itemByPath(path);
         if (item) {
@@ -131,8 +130,8 @@ static QStringList getSelectedCategories(AutoCheckTreeWidget *categoriesView)
     while (*it) {
         QStringList path = categoriesView->pathByItem(*it++);
         if (path.count()) {
-            path.replaceInStrings(CategoryConfig::categorySeparator, QLatin1Char('\\') +
-                                  CategoryConfig::categorySeparator);
+            path.replaceInStrings(CategoryConfig::categorySeparator, QLatin1Char('\\')
+                                  +CategoryConfig::categorySeparator);
             categories.append(path.join(CategoryConfig::categorySeparator));
         }
     }
@@ -183,7 +182,7 @@ void CategoryWidget::setCategoryList(const QStringList &categories)
 void CategoryWidget::addCategory()
 {
     QTreeWidgetItem *newItem = new QTreeWidgetItem(listView(),
-            QStringList(mWidgets->mLineEdit->text()));
+                                                   QStringList(mWidgets->mLineEdit->text()));
     listView()->scrollToItem(newItem);
     listView()->clearSelection();
     newItem->setSelected(true);
@@ -230,11 +229,14 @@ void CategoryWidget::handleColorChanged(const QColor &newColor)
 }
 
 CategoryDialog::CategoryDialog(CategoryConfig *cc, QWidget *parent)
-    : QDialog(parent), d(nullptr)
+    : QDialog(parent)
+    , d(nullptr)
 {
     setWindowTitle(i18n("Select Categories"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel /*| QDialogButtonBox::Help*/ | QDialogButtonBox::Apply, this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(
+        QDialogButtonBox::Ok | QDialogButtonBox::Cancel /*| QDialogButtonBox::Help*/ | QDialogButtonBox::Apply,
+        this);
 
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
@@ -245,7 +247,7 @@ CategoryDialog::CategoryDialog(CategoryConfig *cc, QWidget *parent)
     mainLayout->addWidget(page);
     mainLayout->addWidget(buttonBox);
     QVBoxLayout *lay = new QVBoxLayout(page);
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
 
     mWidgets = new CategoryWidget(cc, this);
     mCategoryConfig = cc;
@@ -257,7 +259,8 @@ CategoryDialog::CategoryDialog(CategoryConfig *cc, QWidget *parent)
     mWidgets->listView()->setFocus();
 
     connect(okButton, &QPushButton::clicked, this, &CategoryDialog::slotOk);
-    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &CategoryDialog::slotApply);
+    connect(buttonBox->button(
+                QDialogButtonBox::Apply), &QPushButton::clicked, this, &CategoryDialog::slotApply);
 }
 
 CategoryDialog::~CategoryDialog()
@@ -320,4 +323,3 @@ void CategoryDialog::setSelected(const QStringList &selList)
 {
     mWidgets->setSelected(selList);
 }
-
