@@ -41,7 +41,7 @@ public:
      * Deletes this editor as well as all editors which are combined into this
      * one.
      */
-    ~CombinedIncidenceEditor();
+    ~CombinedIncidenceEditor() override;
 
     void combine(IncidenceEditor *other);
 
@@ -49,11 +49,11 @@ public:
      * Returns whether or not the current values in the editor differ from the
      * initial values or if one of the combined editors is dirty.
      */
-    bool isDirty() const override;
-    bool isValid() const override;
+    Q_REQUIRED_RESULT bool isDirty() const override;
+    Q_REQUIRED_RESULT bool isValid() const override;
 
     /**
-     * Loads all data from @param inicidence into the combined editors. Note, if
+     * Loads all data from @param incidence into the combined editors. Note, if
      * you reimplement the load method in a subclass, make sure to call this
      * implementation too.
      */
